<?php
// $Id: discogs-release.tpl.php,v 1.1 2011/01/19 16:15:56 karlheinz Exp $

/**
 * @file
 * Display the fields for a discography release
 *
 * Variables available:
 * - $release: array of release information:
 *      - $release['img']: release image URL
 *      - $release['img150']: release image 150px thumbnail URL
 *      Note: Both of the above will be empty if another module is
 *      handling images.
 *      - $release['artist']: release artist
 *      - $release['label']: release label
 *      - $release['cat_num'] release catalogue number
 *      - $release['format']: release format
 *      - $release['country']: country in which this was released
 *      - $release['date']: date of release
 *      - $release['credits']: release credits
 *      - $release['notes']: release notes
 * - $tracks: array of tracks fields:
 *      - $tracks['track_position']: track position
 *          (might not be numeric, e.g. tapes or LP's)
 *      - $track['track_duration']: track duration
 *      - $track['track_artist']: track artist
 *          (for e.g. splits or compilations)
 *      - $track['track_notes']: track notes
 *          (e.g. special credits)
 *      - $track['track_lyrics']: track lyrics
 * - $teaser: whether this is being displayed in Teaser mode
 * - $page: whether this is being displayed as a Page
 *
 */
?>
    <div id="discogs-wrapper">
        <?php if ($release['img']): ?>
        <div id="discogs-img">
            <a href="<?php echo $release['img'] ?>">
                <img src="<?php echo $release['img150'] ?>" />
            </a>
        </div>
        <?php endif ?>
        <?php if ($release['artist']): ?>
        <div id="discogs-artist">
            <span class="label">Artist: </span>
            <span class="data"><?php echo $release['artist'] ?></span>
        </div>
        <?php endif ?>
        <?php if ($release['label']): ?>
        <div id="discogs-label">
            <span class="label">Label: </span>
            <span class="data"><?php echo $release['label'] ?></span>
        </div>
        <?php endif ?>
        <?php if ($release['cat_num']): ?>
        <div id="discogs-cat-num">
            <span class="label">Catalog#: </span>
            <span class="data"><?php echo $release['cat_num'] ?></span>
        </div>
        <?php endif ?>
        <?php if ($release['format']): ?>
        <div id="discogs-format">
            <span class="label">Format: </span>
            <span class="data"><?php echo $release['format'] ?></span>
        </div>
        <?php endif ?>
        <?php if ($release['country']): ?>
        <div id="discogs-country">
            <span class="label">Country: </span>
            <span class="data"><?php echo $release['country'] ?></span>
        </div>
        <?php endif ?>
        <?php if ($release['date']): ?>
        <div id="discogs-date">
            <span class="label">Released: </span>
            <span class="data"><?php echo $release['date'] ?></span>
        </div>
        <?php endif ?>
    <?php if (!$teaser): ?>
        <table id="discogs-tracks">
        <thead>
            <tr>
                <td colspan="4" id="discogs-tracks-label">Tracklist</td>
            </tr>
        </thead>
        <tbody>
        <?php foreach ($tracks as $track): ?>
            <tr class="track-data">
                <td class="track-position">
                    <?php echo strip_tags($track['track_position']) ?>
                </td>
                <td class="track-artists">
                    <?php echo strip_tags($track['track_artist']) ?>
                </td>
                <td class="track-title">
                    <?php echo strip_tags($track['track_title']) ?>
                </td>
                <td class="track-duration">
                    <?php echo(empty($track['track_duration'])
                    ? '&nbsp;' : strip_tags($track['track_duration'])) ?>
                </td>
            </tr>
            <?php if (!empty($track['track_notes'])): ?>
            <tr class="track-notes">
                <td>&nbsp;</td>
                <td class="label">Notes:</td>
                <td class="field" colspan="2">
                    <?php echo $track['track_notes'] ?>
                </td>
            </tr>
            <?php endif ?>
            <?php if (!empty($track['track_lyrics'])): ?>
            <tr class="track-lyrics">
                <td>&nbsp;</td>
                <td class="label">Lyrics:</td>
                <td class="field" colspan="2">
                    <?php echo $track['track_lyrics'] ?>
                </td>
            </tr>
            <?php endif ?>
        <?php endforeach; ?>
        </tbody>
        </table>
        <?php if ($release['credits']): ?>
        <div id="discogs-credits">
            <span class="label">Credits </span>
            <span class="data"><?php echo $release['credits'] ?></span>
        </div>
        <?php endif ?>
        <?php if ($release['notes']): ?>
        <div id="discogs-notes">
            <span class="label">Notes </span>
            <span class="data"><?php echo $release['notes'] ?></span>
        </div>
        <?php endif ?>
    <?php endif ?>
    </div>