<?php
// $Id: discogs.admin.inc,v 1.1 2011/01/19 16:15:56 karlheinz Exp $
/**
 * @file
 * Administration page callbacks for the discogs module.
 */

/**
 * Form builder for Discogs admin settings.
 *
 * @ingroup forms
 * @see system_settings_form()
 * @see discogs.module.discogs_menu()
 */
function discogs_admin_settings() {
  $form['discogs_api_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Discogs.com API key'),
    '#default_value' => variable_get('discogs_api_key', 'ae26686b33'),
    '#description' => t('This is the API key which you should get from
      <a href="@durl">Discogs.com</a>. It defaults to my own; however, each
      Drupal site should have its own API key, to prevent the limit that
      Discogs places on queries per API key.',
      array('@durl' => 'http://www.discogs.com/users/api_key')),
    '#size' => 10,
    '#maxlength' => 10,
  );
  // If the user does not set an image directory, it defaults to Drupal's temp
  // directory in files
  $tempdir = variable_get('file_directory_temp', '');
  $form['discogs_img_dir'] = array(
    '#type' => 'textfield',
    '#title' => t('Discogs image directory'),
    '#default_value' => variable_get('discogs_img_dir', $tempdir),
    '#description' => t('This is a sub-directory of Drupal\'s default
      files directory, which will hold images imported from
      Discogs.com. If an image handling module is available, images
      will be stored here temporarily before being passed to that
      module. If not, images will be served directly from here.'),
    '#size' => 10,
    '#maxlength' => 32,
  );
  // Allow users to choose their image handler
  $options = array(0 => t("None (store local URL's only)"));
  if (module_exists('upload')) {
    $options[1] = t('Drupal core file upload');
  }
  if (module_exists('imagefield')) {
    $options[2] = t('CCK Imagefield');
  }
  if (module_exists('image_attach')) {
    $options[3] = t("Image module's image_attach");
  }
  $form['discogs_img_handler'] = array(
    '#type' => 'select',
    '#title' => t('Image handler'),
    '#options' => $options,
    '#default_value' => variable_get('discogs_img_handler', 0),
    '#description' => t('Choose your image handling module. Only activated
      modules will be presented here. It is recommended that you make
      your choice before you start adding releases, as images created
      with one image handling module will NOT be available to any
      other image handling modules.'),
  );

  // Custom submit button for changing image handlers
  $form['#submit'][] = 'discogs_admin_settings_submit';
  return system_settings_form($form);
}

function discogs_admin_settings_submit($form, &$form_state) {
  switch ($form_state['values']['discogs_img_handler']) {
    case 0: // Native image handling
      // Deactivate upload, imagefield and image_attach
      variable_set('image_attach_discogs', 0);
      variable_set('upload_discogs', 0);
      _discogs_cck_imagefield(FALSE);
      break;
    case 1: // Drupal core upload
      // Deactivate imagefield and image_attach, activate upload
      variable_set('image_attach_discogs', 0);
      variable_set('upload_discogs', 1);
      _discogs_cck_imagefield(FALSE);
      break;
    case 2: // CCK Imagefield
      // Deactivate upload and image_attach, activate imagefield
      variable_set('image_attach_discogs', 0);
      variable_set('upload_discogs', 0);
      _discogs_cck_imagefield();
      break;
    case 3: // Image module's image_attach
      // Deactivate upload and imagefield, activate image_attach
      variable_set('image_attach_discogs', 1);
      variable_set('image_attach_existing', 1);
      variable_set('upload_discogs', 0);
      _discogs_cck_imagefield(FALSE);
      break;
  }
}

/**
 * Creates or deletes a CCK imagefield called 'field_discogs_cover' for the
 * Discogs content type.
 *
 * @param $create
 *   Boolean TRUE = Create field, FALSE = Delete field (default TRUE)
 * @return
 *   Boolean TRUE on success, FALSE on failure
 */
function _discogs_cck_imagefield($create = TRUE) {
  // So this function can be called even if Imagefield isn't installed
  if (!module_exists('imagefield')) {
    return FALSE;
  }
  module_load_include('inc', 'imagefield', 'imagefield_widget');
  module_load_include('inc', 'filefield', 'filefield_widget');
  module_load_include('inc', 'content', 'includes/content.crud');

  // Taken from a CCK export
  $field = array(
    'label' => t('Cover'),
    'type_name' => 'discogs',
    'field_name' => 'field_discogs_cover',
    'type' => 'filefield',
    'widget_type' => 'imagefield_widget',
    'change' => 'Change basic information',
    'weight' => '-4',
    'file_extensions' => 'png gif jpg jpeg',
    'progress_indicator' => 'bar',
    'file_path' => '',
    'max_filesize_per_file' => '',
    'max_filesize_per_node' => '',
    'max_resolution' => 0,
    'min_resolution' => 0,
    'custom_alt' => 0,
    'alt' => '',
    'custom_title' => 0,
    'title_type' => 'textfield',
    'title' => '',
    'use_default_image' => 0,
    'default_image_upload' => '',
    'default_image' => NULL,
    'description' => t('Release image (album cover, DVD cover, etc)'),
    'required' => 0,
    'multiple' => '1',
    'list_field' => '0',
    'list_default' => 1,
    'description_field' => '0',
    'op' => 'Save field settings',
    'module' => 'filefield',
    'widget_module' => 'imagefield',
    'columns' => array(
      'fid' => array(
        'type' => 'int',
        'not null' => FALSE,
        'views' => TRUE,
      ),
      'list' => array(
        'type' => 'int',
        'size' => 'tiny',
        'not null' => FALSE,
        'views' => TRUE,
      ),
      'data' => array(
        'type' => 'text',
        'serialize' => FALSE,
        'views' => TRUE,
      ),
    ),
    'display_settings' => array(
      'label' => array(
        'format' => 'above',
        'exclude' => 0,
      ),
      'teaser' => array(
        'format' => 'image_plain',
        'exclude' => 0,
      ),
      'full' => array(
        'format' => 'image_plain',
        'exclude' => 0,
      ),
      4 => array(
        'format' => 'image_plain',
        'exclude' => 0,
      ),
    ),
  );

  if (module_exists('imagefield_tokens')) {
    $field['alt'] = '[title]';
    $field['title'] = '[title]';
  }

  if ($create) {
    content_field_instance_create($field);
    variable_set('discogs_img_handler', 2);
  }
  else {
    content_field_instance_delete($field['field_name'], $field['type_name'], TRUE);
  }
  return TRUE;
}